# resource

## Objects

 * <span class="badge object-type-class"></span> [Manifest](./object-Manifest.md)
 * <span class="badge object-type-class"></span> [Metadata](./object-Metadata.md)
## Builders

 * <span class="badge builder"></span> [Manifest](./builder-Manifest.md)
 * <span class="badge builder"></span> [Metadata](./builder-Metadata.md)
